@@ -1,7 +1,7 @@
 package Scrappy::Project::Document;
 
 BEGIN {
-    $Scrappy::Project::Document::VERSION = '0.921111901';
+    $Scrappy::Project::Document::VERSION = '0.92111220';
 }
 
 use Moose::Role;
@@ -18,9 +18,8 @@ has fields => (
         for ($self->meta->get_all_methods) {
             push @fields, $_->name
               if $_->package_name eq ref $self
-                  &&
-
-                     $_->name ne 'meta'
+                  && $_->name ne 'meta'
+                  && $_->name ne 'scraper'
                   && $_->name ne 'fields'
                   && $_->name ne 'parse'
                   && $_->name ne 'records'
@@ -50,6 +49,7 @@ sub parse {
 
     my $record = {};
     map { $record->{$_} = $self->$_($self->scraper, $vars) } @{$self->fields};
+    $record->{url} = $self->scraper->url->as_string;
     push @{$self->records}, $record;
 
     return $record;
